/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { BaseEvent } from './base-event';
/**
 * Fired when a [GeoJSON Feature](https://geojson.org/geojson-spec.html#feature-objects) is created on a shape layer.
 */
export class ShapeFeatureCreatedEvent extends BaseEvent {
    /**
     * The original data item for this Feature. Members include `geometries` and `properties`.
     */
    dataItem;
    /**
     * The shape layer instance.
     */
    layer;
    /**
     * The group containing feature shape instances.
     */
    group;
    /**
     * A reference to the `dataItem.properties` object.
     */
    properties;
    /**
     * @hidden
     */
    constructor(e, sender) {
        super(sender);
        this.dataItem = e.dataItem;
        this.layer = e.layer;
        this.group = e.group;
        this.properties = e.properties;
    }
}
