/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { BaseEvent } from './base-event';
/**
 * Fired when the mouse enters a shape.
 *
 * > This event will fire reliably only for shapes that have set fill color.
 * > The opacity can still be set to 0 so the shapes appear to have no fill.
 */
export class ShapeMouseEnterEvent extends BaseEvent {
    /**
     * The shape layer instance.
     */
    layer;
    /**
     * The shape instance.
     */
    shape;
    /**
     * The source DOM event instance
     */
    originalEvent;
    /**
     * @hidden
     */
    constructor(e, sender) {
        super(sender);
        this.layer = e.layer;
        this.shape = e.shape;
        this.originalEvent = e.originalEvent;
    }
}
