/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectionStrategy, Component, forwardRef, Input } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';
import { CollectionService } from '../common/collection.service';
import { ConfigurationService } from '../common/configuration.service';
import { LayerComponent } from './layer.component';
import * as i0 from "@angular/core";
import * as i1 from "../common/configuration.service";
import * as i2 from "../common/collection.service";
import * as i3 from "@angular/platform-browser";
/**
 * Defines a vector shape layer bound to GeoJSON data. [See example](slug:tile_layers_map).
 */
export class TileLayerComponent extends LayerComponent {
    configurationService;
    collectionService;
    sanitizer;
    /**
     * The size of the image tile in pixels.
     *
     * @default 256
     */
    tileSize;
    /**
     * A list of subdomains to use for loading tiles.
     *
     * Alternating between different subdomains allows more requests to be executed in parallel.
     */
    subdomains;
    /**
     * A function that returns an image URL for each tile position.
     */
    urlTemplate;
    constructor(configurationService, collectionService, sanitizer) {
        super('tile', configurationService, collectionService, sanitizer);
        this.configurationService = configurationService;
        this.collectionService = collectionService;
        this.sanitizer = sanitizer;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TileLayerComponent, deps: [{ token: i1.ConfigurationService }, { token: i2.CollectionService }, { token: i3.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: TileLayerComponent, isStandalone: true, selector: "kendo-map-tile-layer", inputs: { tileSize: "tileSize", subdomains: "subdomains", urlTemplate: "urlTemplate" }, providers: [
            ConfigurationService,
            {
                provide: LayerComponent,
                useExisting: forwardRef(() => TileLayerComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: '', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TileLayerComponent, decorators: [{
            type: Component,
            args: [{
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    providers: [
                        ConfigurationService,
                        {
                            provide: LayerComponent,
                            useExisting: forwardRef(() => TileLayerComponent)
                        }
                    ],
                    selector: 'kendo-map-tile-layer',
                    template: '',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.ConfigurationService }, { type: i2.CollectionService }, { type: i3.DomSanitizer }]; }, propDecorators: { tileSize: [{
                type: Input
            }], subdomains: [{
                type: Input
            }], urlTemplate: [{
                type: Input
            }] } });
