/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { MapLayer, MapShapeFeatureCreatedEvent } from '@progress/kendo-charts';
import { Group } from '@progress/kendo-drawing';
import { MapComponent } from '../map.component';
import { BaseEvent } from './base-event';
/**
 * Fired when a [GeoJSON Feature](https://geojson.org/geojson-spec.html#feature-objects) is created on a shape layer.
 */
export declare class ShapeFeatureCreatedEvent extends BaseEvent implements MapShapeFeatureCreatedEvent {
    /**
     * The original data item for this Feature. Members include `geometries` and `properties`.
     */
    dataItem: any;
    /**
     * The shape layer instance.
     */
    layer: MapLayer;
    /**
     * The group containing feature shape instances.
     */
    group: Group;
    /**
     * A reference to the `dataItem.properties` object.
     */
    properties: any;
    /**
     * @hidden
     */
    constructor(e: MapShapeFeatureCreatedEvent, sender: MapComponent);
}
