/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DomSanitizer } from '@angular/platform-browser';
import { BubbleLayerOptions, BubbleLayerSymbol } from '@progress/kendo-charts';
import { ShapeOptions } from '@progress/kendo-drawing';
import { CollectionService } from '../common/collection.service';
import { ConfigurationService } from '../common/configuration.service';
import { LayerComponent } from './layer.component';
import * as i0 from "@angular/core";
/**
 * A vector shape layer for bubble maps. [See example](slug:bubble_layers_map).
 */
export declare class BubbleLayerComponent extends LayerComponent implements BubbleLayerOptions {
    protected configurationService: ConfigurationService;
    protected collectionService: CollectionService;
    protected sanitizer: DomSanitizer;
    /**
     * The array of data items for this layer.
     */
    data?: any[];
    /**
     * The data item field which contains the symbol location.
     *
     * The field should be an array with two numbers - latitude and longitude in decimal degrees.
     */
    locationField?: string;
    /**
     * The value field for the symbols used to determine their relative size.
     * The data item field should be a number.
     */
    valueField?: string;
    /**
     * The symbol to use for bubble layers.
     */
    symbol?: BubbleLayerSymbol;
    /**
     * The default style for symbols.
     */
    style?: ShapeOptions;
    /**
     * The maximum symbol size for bubble layer symbols.
     *
     * @default 100
     */
    maxSize?: number;
    /**
     * The minimum symbol size for bubble layer symbols.
     * Setting non-zero value will distort symbol area to value ratio.
     *
     * @default 0
     */
    minSize?: number;
    constructor(configurationService: ConfigurationService, collectionService: CollectionService, sanitizer: DomSanitizer);
    static ɵfac: i0.ɵɵFactoryDeclaration<BubbleLayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BubbleLayerComponent, "kendo-map-bubble-layer", never, { "data": { "alias": "data"; "required": false; }; "locationField": { "alias": "locationField"; "required": false; }; "valueField": { "alias": "valueField"; "required": false; }; "symbol": { "alias": "symbol"; "required": false; }; "style": { "alias": "style"; "required": false; }; "maxSize": { "alias": "maxSize"; "required": false; }; "minSize": { "alias": "minSize"; "required": false; }; }, {}, never, never, true, never>;
}
