/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DomSanitizer } from '@angular/platform-browser';
import { MarkerLayerOptions } from '@progress/kendo-charts';
import { CollectionService } from '../common/collection.service';
import { ConfigurationService } from '../common/configuration.service';
import { LayerComponent } from './layer.component';
import * as i0 from "@angular/core";
/**
 * A vector shape layer for bubble maps. [See example](slug:marker_layers_map).
 */
export declare class MarkerLayerComponent extends LayerComponent implements MarkerLayerOptions {
    protected configurationService: ConfigurationService;
    protected collectionService: CollectionService;
    protected sanitizer: DomSanitizer;
    /**
     * The array of data items for this layer.
     */
    data?: any[];
    /**
     * The data item field which contains the marker location.
     *
     * The field should be an array with two numbers - latitude and longitude in decimal degrees.
     */
    locationField?: string;
    /**
     * The data item field which contains the marker title.
     */
    titleField?: string;
    /**
     * The default marker shape for data-bound markers. Supported marker shapes are "pinTarget and "pin".
     *
     * Marker shapes are implemented as CSS classes on the marker element (`span.k-marker`). For example "pinTarget" is rendered as `k-marker-pin-target`.
     */
    shape?: string | 'pinTarget' | 'pin';
    constructor(configurationService: ConfigurationService, collectionService: CollectionService, sanitizer: DomSanitizer);
    static ɵfac: i0.ɵɵFactoryDeclaration<MarkerLayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MarkerLayerComponent, "kendo-map-marker-layer", never, { "data": { "alias": "data"; "required": false; }; "locationField": { "alias": "locationField"; "required": false; }; "titleField": { "alias": "titleField"; "required": false; }; "shape": { "alias": "shape"; "required": false; }; }, {}, never, never, true, never>;
}
