/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DomSanitizer } from '@angular/platform-browser';
import { TileLayerOptions, TileUrlTemplateArgs } from '@progress/kendo-charts';
import { CollectionService } from '../common/collection.service';
import { ConfigurationService } from '../common/configuration.service';
import { LayerComponent } from './layer.component';
import * as i0 from "@angular/core";
/**
 * Defines a vector shape layer bound to GeoJSON data. [See example](slug:tile_layers_map).
 */
export declare class TileLayerComponent extends LayerComponent implements TileLayerOptions {
    protected configurationService: ConfigurationService;
    protected collectionService: CollectionService;
    protected sanitizer: DomSanitizer;
    /**
     * The size of the image tile in pixels.
     *
     * @default 256
     */
    tileSize: number;
    /**
     * A list of subdomains to use for loading tiles.
     *
     * Alternating between different subdomains allows more requests to be executed in parallel.
     */
    subdomains: string[];
    /**
     * A function that returns an image URL for each tile position.
     */
    urlTemplate: (args: TileUrlTemplateArgs) => string;
    constructor(configurationService: ConfigurationService, collectionService: CollectionService, sanitizer: DomSanitizer);
    static ɵfac: i0.ɵɵFactoryDeclaration<TileLayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TileLayerComponent, "kendo-map-tile-layer", never, { "tileSize": { "alias": "tileSize"; "required": false; }; "subdomains": { "alias": "subdomains"; "required": false; }; "urlTemplate": { "alias": "urlTemplate"; "required": false; }; }, {}, never, never, true, never>;
}
